import * as React from 'react';
import classNames from 'classnames';
import type { FC } from "react";
import Style from './style/PageBanner.module.less'
import Link from 'next/link'
import IconFont from "@/assets/iconfont";
import { motion, Variants } from "framer-motion"
import {useMemo} from "react";

interface Items {
  title?: React.ReactNode;
}

export interface PageBannerProps {
  src?: string;
  title?: string;
  items?: Items[];
}

const item: Variants = {
  hidden: {
    y: 50,
    opacity: 0,
  },
  visible: {
    y: 0,
    opacity: 1,
    transition: {
      duration: 0.8
    }
  },
};

const PageBanner: FC<PageBannerProps> = (props) => {
  const {
    src,
    title,
    items,
  } = props

  const lenght = useMemo(() => {
    if (items?.length) {
      return items.length - 1
    }
    return 0
  }, [items])

  const list = items?.map((v: Items, index) => {
    const title = v.title
    const last = lenght === index
    const isString = typeof title === 'string'
    return (
      <li className={Style['nav-item']} key={index}>
        {
          isString ?  <div>{title}</div> : title
        }
        {
          last ? null : (
            <IconFont name="right" size={12} className={Style.icon} color="#fff" />
          )
        }
      </li>
    )
  })

  return (
    <div className={Style.pageBannerBlock}>
      <div
        className={Style['banner-bg']}
        style={{
          backgroundImage: src ? `url(${src})` : ''
        }}
      >
        <div className={Style.container}>
          <motion.div
            className={classNames(Style.content, 'container')}
            initial="hidden"
            animate="visible"
            transition={{
              staggerChildren: 0.3,
              delayChildren: 0.3
            }}
          >
            <motion.ul variants={item} className={Style['nav-list']}>
              {list}
            </motion.ul>
            <motion.div variants={item} className={Style.title}>
              {title}
            </motion.div>
          </motion.div>
          <div className={Style.line}></div>
        </div>
      </div>
    </div>
  )
}

export default PageBanner
