import {FC, useEffect, useMemo, useState} from "react";
import cx from 'classnames'
import { motion } from "framer-motion"
import Style from './index.module.less'

interface BitzLanguageProps {
  lang?: any;
  changeEmit?:(val:string)=>void
}


const BitzLanguage: FC<BitzLanguageProps> = ({
  lang='CHS',
  changeEmit=()=>{}
}) => {
   const [changeLang,setChangeLang]=useState<string>('')

   const newChangeLang=useMemo(()=>{
    return lang
   },[lang])

   useEffect(()=>{
    setChangeLang(newChangeLang)
   },[newChangeLang])


  return (
    <div className={Style.bitzLanguageBlock}>
      <div
        onClick={() => {
          setChangeLang('CHS')
          changeEmit('CHS')
        }}
        className={cx(Style.Item, { [Style.active]:changeLang=='CHS' })}
      >
        <div className={Style.text}>中</div>
        {
          changeLang=='CHS' ? <motion.div initial={false} className={Style.underline} layoutId="underline" /> : null
        }
      </div>
      <div
        onClick={() => {
          setChangeLang('ENG')
          changeEmit('ENG')
        }}
        className={cx(Style.Item, { [Style.active]: changeLang=='ENG' })}
      >
        <div>EN</div>
        {
          changeLang=='ENG' ? <motion.div  initial={false} className={Style.underline} layoutId="underline" /> : null
        }
      </div>
    </div>
  )
}

export default BitzLanguage
