import { FC, useEffect, useMemo, useState } from 'react'
import { Pagination } from 'antd'
import styles from './index.module.less'

interface BitzPaginationProps {
  /**
   * 是否展示 pageSize 切换器
   */
  showSizeChanger?:boolean
  /**
   * 指定每页可以显示多少条
   */
  pageSizeOptions?: string[] | number[]
  /**
   * 数据总数
   */
  total?: number
  /**
   * 接口返回的数据
   */
  dataSource?: any[]
  /**
   * 父级给子组件的page
   */
  formPage?: number
  /**
   * 给父组件传值 page当前第几页  pageSize每页有多少
   */
  paginationEmit?: (page: number, pageSize: number) => void
  /**
   * 默认是end(右);left(左);center(居中)
   */
  direction?: string
  /**
   * 分页数量
   */
  pageSizes?:number
}

let pageChange: boolean = true

const BitzPagination: FC<BitzPaginationProps> = ({
  showSizeChanger=false,
  pageSizeOptions = [10, 20, 50, 100],
  pageSizes,
  total = 0,
  dataSource = [],
  formPage,
  paginationEmit = () => {},
  direction = 'center',
}) => {
  const [page, setPage] = useState<number>(formPage || 1)
  const [pageSize, setPageSize] = useState<number>(9)



  const newPageSize=useMemo(()=>{
    return pageSizes||0
  },[pageSizes])


  useEffect(()=>{
    if(newPageSize){
      setPageSize(newPageSize)
    }
  },[newPageSize])




  const onChange = (page: number, pageSize: number) => {
    setPage(page)
    if (pageChange) {
      paginationEmit(page, pageSize)
    }
  }

  const onShowSizeChange = (page: number, pageSize: number) => {
    pageChange = false
    setPageSize(pageSize)
    setTimeout(() => {
      setPage(1)
      paginationEmit(1, pageSize)
      setTimeout(() => {
        pageChange = true
      }, 100)
    }, 100)
  }

  return (
    <>
      {dataSource?.length != 0 && (
        <div className={styles.bitzPaginationBlock} style={{ justifyContent: direction }}>
          <Pagination
            size="small"
            total={total}
            defaultCurrent={page}
            current={page}
            pageSize={pageSize}
            showSizeChanger={showSizeChanger}
            showQuickJumper={false}
            pageSizeOptions={pageSizeOptions}
            showTotal={(total) => `共 ${total} 条数据`}
            onChange={onChange}
            onShowSizeChange={onShowSizeChange}
          />
        </div>
      )}
    </>
  )
}

export default BitzPagination
