import type { CSSProperties, FC } from 'react'
import Style from './index.module.less'
import IconFont from "@/assets/iconfont";
import {KeyboardEventHandler, useEffect, useState} from "react";
import { isUndefined } from 'lodash-es'
import cx from 'classnames'

export interface BitzSearchProps {
  placeholder?: string;
  /**
   * 语义化结构 style
   */
  styles?: CSSProperties | undefined;
  /**
   * 语义化结构 class
   */
  classNames?: string;
  /**
   * 图标语义化结构 style
   */
  iconStyles?: CSSProperties | undefined;
  /**
   * 图标语义化结构 class
   */
  iconClassNames?: string;
  /**
   * 输入框内容变化时的回调
   */
  onChange?: (age?: string) => void;
  /**
   * 输入框内容
   */
  value?: string;
  /**
   * 输入框默认内容
   */
  defaultValue?: string;
  /**
   * 按下回车的回调
   */
  onPressEnter?: (age?: string) => void;
}

const BitzSearch: FC<BitzSearchProps> = (props) => {
  const {
    styles,
    classNames,
    iconStyles,
    iconClassNames,
    placeholder = '请输入'
  } = props
  const [value, setValue] = useState(props?.defaultValue)

  const handleKeyDown: KeyboardEventHandler<HTMLInputElement> = (event) => {
    if (event.key === 'Enter') {
      // 处理回车事件
      // console.log("回车键已按下！");
      // props?.onChange?.(value)
      props?.onPressEnter?.(value)
    }
  }

  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const value = e?.target?.value
    props?.onChange?.(value)
    if (isUndefined(props?.value)) {
      setValue(value)
    }
  }

  useEffect(() => {
    if (!isUndefined(props?.value)) {
      setValue(props?.value)
    }
  }, [props?.value])

  return (
    <div className={cx(Style.bitzSearchBlock, classNames)} style={styles}>
      <input
        value={value}
        onChange={handleChange}
        onKeyDown={handleKeyDown}
        placeholder={placeholder}
        className={Style.input}
        type="text"
      />
      <div className="px-2">
        <IconFont
          className={cx(Style.searchBtn, iconClassNames)}
          style={iconStyles}
          color="#333"
          size={24}
          name="chazhao"
        />
      </div>
    </div>
  )
}

export default BitzSearch
