import styles from "./index.module.less";
import { FC, useState, ReactNode } from "react";

interface BitzSelect {
  className?: string | number;
  activeKey?: string | number;
  items?: { label: string; key: string | number; children: ReactNode }[];
  renderItem?: () => ReactNode;
  onTabClick?: (key?: string | number, event?: MouseEvent) => void;
}

const BitzSelect: FC<BitzSelect> = ({
  className = "text-center",
  activeKey,
  items,
  renderItem,
  onTabClick,
}) => {
  const [ctx, setCtx] = useState({
    activeKey,
  });

  function renderitems() {
    if (renderItem) {
      return renderItem?.();
    }
    return items?.map((item, index) => (
      <div
        key={index}
        className={`${item.key === ctx.activeKey ? "block" : "hidden"}`}
      >
        {item.children}
      </div>
    ));
  }

  return (
    <div
      style={{ background: "#fff" }}
      className={`bitzTabsBlock w-full text-left relative ${className}`}
    >
      <div className="cursor-pointer w-full border-b-2">
        {items?.map((item, key) => (
          <div
            className={`inline-block p-4 text-center mb-[-2px] ${
              ctx.activeKey === item.key ? styles["active-tab"] : ""
            }`}
            key={key}
            onClick={(e?: any) => {
              setCtx((prev) => ({ ...prev, activeKey: item.key }));
              onTabClick?.(item.key, e);
            }}
          >
            {item.label}
          </div>
        ))}
      </div>
      <div>{renderitems()}</div>
    </div>
  );
};

export default BitzSelect;
